local origfunc = GuiTweakData.init
function GuiTweakData:init(...)
	origfunc(self, ...)
	
	self.new_heists = {limit = 1}

	table.insert(self.new_heists, { run_to_get = GuiTweakData.suggestion_least_played})
end

function GuiTweakData:suggestion_least_played()
	local jobs = deep_clone(tweak_data.narrative:get_jobs_index())
	
	for i = 1, #jobs do
		local i_played = managers.crimenet:get_last_played_job(jobs[i])

		for j = i, #jobs do
			local j_played = managers.crimenet:get_last_played_job(jobs[j])
			if i_played and j_played
				and i_played._value > j_played._value
			then
				local temp = jobs[i]
				jobs[i] = jobs[j]
				jobs[j] = temp
			end
		end
	end
	
	local temp_jobs = jobs
	jobs = {}
	for i = 1, #temp_jobs do
		local contact = (tweak_data.narrative:job_data(temp_jobs[i])).contact
		local contact_td = tweak_data.narrative.contacts[contact]
		if not (contact_td and contact_td.hidden)
			and not tweak_data.narrative:is_wrapped_to_job(temp_jobs[i])
		then
			local job_td = tweak_data.narrative:job_data(temp_jobs[i])
			if job_td and
				(not job_td.dlc
					or managers.dlc:is_dlc_unlocked(job_td.dlc))
			then
				jobs[#jobs + 1] = temp_jobs[i]
			end
		end
	end
	
	--for i = 1, #jobs do
	--	log(jobs[i])
	--end
	local selection_index = math.floor(#jobs * 0.15)
	local picked = jobs[math.random(selection_index)]
	
	local picked_td = tweak_data.narrative:job_data(picked)
	
	local path = ''
	if picked_td.contract_visuals
		and picked_td.contract_visuals.preview_image
	then
		local data = picked_td.contract_visuals.preview_image

		if data.id then
			path = "guis/dlcs/" .. (data.folder or "bro") .. "/textures/pd2/crimenet/" .. data.id
		end
	end
	
	local picked_name_id = (tweak_data.narrative:job_data(picked)).name_id
	
	return {
		name_id = picked_name_id,
		texture_path = path,
		func = function()
				local function new_lobby(difficulty, od)
					MenuCallbackHandler:create_lobby()
					local difficulty_id = tweak_data:difficulty_to_index(difficulty)
					managers.money:on_buy_premium_contract(picked, difficulty_id)
					managers.job:on_buy_job(picked, difficulty_id)
					MenuCallbackHandler:start_job({job_id = picked, difficulty = difficulty, one_down = od or false})
					MenuCallbackHandler:save_progress()
				end
		
				local menuoptions = {}
				
				for i = 5, #tweak_data.difficulties do
					local diff = tweak_data.difficulty_name_ids[tweak_data.difficulties[i]]
					menuoptions[#menuoptions + 1] = {
									text = managers.localization:to_upper_text(diff),
									callback = function()
													new_lobby(tweak_data.difficulties[i], false)
												end
								}
				end
				
				for i = 5, #tweak_data.difficulties do
					local diff = tweak_data.difficulty_name_ids[tweak_data.difficulties[i]]
					menuoptions[#menuoptions + 1] = {
										text = managers.localization:to_upper_text(diff)..' '..managers.localization:to_upper_text("menu_one_down"),
										callback = function()
														new_lobby(tweak_data.difficulties[i], true)
													end
									}
				end
				
				menuoptions[#menuoptions + 1] = {
        									text = 'CANCEL',
        									is_cancel_button = true,
    									}
				
				QuickMenu:new(
						"Difficulty", 
						"Choose a difficulty to play "..managers.localization:text(picked_name_id),
						  menuoptions	
				 ):Show()
			end
	}
end