local PANEL_PADDING = 10
local IMAGE_H = 123
local IMAGE_W = 416
local TIME_PER_PAGE = 6
local CHANGE_TIME = 0.5
local SPOT_W = 32
local SPOT_H = 8
local BAR_W = 32
local BAR_H = 6
local BAR_X = (SPOT_W - BAR_W) / 2
local BAR_Y = 0

-- most of the code is unchanged
function NewHeistsGui:init(ws, fullscreen_ws)
	local tweak = tweak_data.gui.new_heists
	self._page_count = math.min(#tweak, tweak.limit)

---- can't run that function in guitweakdata:init()
----  because it uses global tweak_data which does not exist there yet
	for k,v in pairs(tweak or {}) do
		if type(v) == 'table' and v.run_to_get then
			tweak[k] = v.run_to_get(v.param)
		end
	end
	
	self._current_page = 1
	self._block_change = false
	self._highlighted = false
	self._ws = ws
	self._fullscreen_ws = fullscreen_ws
	self._panel = ws:panel()
	self._full_panel = fullscreen_ws:panel()
	self._content_panel = self._full_panel:panel({w = IMAGE_W})

	self._content_panel:set_right(self._panel:width())

	local header_h = tweak_data.menu.pd2_small_font_size + PANEL_PADDING
	self._contents = {}
	self._internal_content_panel = self._content_panel:panel()
	self._internal_image_panel = self._internal_content_panel:panel({
		y = header_h,
		h = IMAGE_H
	})
	local max_h = 0
	self._font_size = tweak_data.menu.pd2_small_font_size
	self._text = self._internal_content_panel:text({
		text = "ASDF",
		font = tweak_data.menu.pd2_small_font,
		font_size = self._font_size,
		y = PANEL_PADDING - 5
	})

	self:_set_text(managers.localization:to_upper_text(tweak[1].name_id))

	for i = 1, self._page_count, 1 do
		local content_panel = self._internal_content_panel:panel({x = (i == 1 and 0 or 1) * self._content_panel:w()})
		local image_panel = content_panel:panel({
			y = header_h,
			height = IMAGE_H
		})

-------- here H and W are added to make the image fit
		image_panel:bitmap({
			texture = tweak[i].texture_path,
			h = IMAGE_H,
			w = IMAGE_W})
		content_panel:set_h(image_panel:bottom())

		max_h = math.max(max_h, image_panel:bottom())

		table.insert(self._contents, content_panel)
	end

	BoxGuiObject:new(self._internal_image_panel, {sides = {
		1,
		1,
		1,
		1
	}})

	self._selected_box = BoxGuiObject:new(self._internal_image_panel, {sides = {
		2,
		2,
		2,
		2
	}})

	self._selected_box:set_visible(false)
	self._internal_content_panel:set_h(max_h)

	self._page_panel = self._content_panel:panel({
		h = 16,
		y = self._internal_content_panel:bottom() + PANEL_PADDING
	})
	self._page_buttons = {}

	for i = 1, self._page_count, 1 do
		local page_button = self._page_panel:bitmap({texture = "guis/textures/pd2/ad_spot"})

		page_button:set_center_x((i / (self._page_count + 1) * self._page_panel:w()) / 2 + self._page_panel:w() / 4)
		page_button:set_center_y((self._page_panel:h() - page_button:h()) / 2)
		table.insert(self._page_buttons, page_button)
	end

	self._content_panel:set_h(self._page_panel:bottom())

	if managers.menu_component._player_profile_gui then
		local wx = self._content_panel:world_x()
		local wy = managers.menu_component._player_profile_gui._panel:world_y()
		wx, wy = managers.gui_data:convert_pos(ws, fullscreen_ws, wx, wy)

		self._content_panel:set_world_y(wy - header_h)
		self._content_panel:set_x(wx)
	else
		self._content_panel:set_bottom(self._panel:height() - PANEL_PADDING * 2)
	end

	self._bar = self._page_panel:bitmap({
		texture = "guis/textures/pd2/shared_lines",
		valign = "grow",
		halign = "grow",
		wrap_mode = "wrap",
		x = BAR_X,
		y = BAR_Y,
		w = BAR_W,
		h = BAR_H
	})

	self:set_bar_width(BAR_W, true)
	self._bar:set_top(self._page_buttons[1]:top() + BAR_Y)
	self._bar:set_left(self._page_buttons[1]:left() + BAR_X)

	self._select_rect = self._full_panel:bitmap({
		texture = "guis/textures/pd2/ad_blue2",
		layer = -2
	})

	self._select_rect:set_visible(false)
	self._select_rect:set_bottom(self._full_panel:height())
	self._select_rect:set_right(self._full_panel:width())

	self._queued_page = nil

	self:try_get_dummy()
end

function NewHeistsGui:mouse_pressed(button, x, y)
	if not self._enabled or button ~= Idstring("0") then
		return
	end

	x, y = managers.gui_data:convert_pos(self._ws, self._fullscreen_ws, x, y)

	if not self._content_panel:inside(x, y) then
		return
	end

	if self._internal_image_panel:inside(x, y) and self._contents[self._current_page]:inside(x, y) then
		if tweak_data.gui.new_heists[self._current_page].func then
			tweak_data.gui.new_heists[self._current_page].func()
		else
			Steam:overlay_activate("url", tweak_data.gui.new_heists[self._current_page].url)
		end

		return true
	end

	for i, button in ipairs(self._page_buttons) do
		if i ~= self._current_page and button:inside(x, y) then
			self:_move_to_page(i)

			return true
		end
	end
end